"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
const propertiesTmpl = (properties) => {
    return (properties || [])
        .map((property) => {
        const { type, name, description } = property;
        const res = [];
        name && res.push(name);
        if (type.names.length) {
            res.length && res.push(': ');
            res.push(`\`${type.names.join(' | ')}\``);
        }
        description && res.push(description);
        return res.join('');
    })
        .join('\n');
};
const tmpl = (events, lang) => {
    const displayableEvents = events.filter((event) => { var _a; return event.description || ((_a = event.tags) === null || _a === void 0 ? void 0 : _a.length); });
    const hasVersion = displayableEvents.some((event) => { var _a; return (_a = event === null || event === void 0 ? void 0 : event.tags) === null || _a === void 0 ? void 0 : _a.some((tag) => tag.title === 'version'); });
    const content = displayableEvents
        .map((event) => {
        const { name, tags } = event;
        let { description } = event;
        let version = '';
        if (tags === null || tags === void 0 ? void 0 : tags.length) {
            for (const item of tags) {
                if (item.title === 'version') {
                    version = item.content;
                    continue;
                }
                if (item.title === lang) {
                    description = item.content;
                }
            }
        }
        let lineContent = `|${(0, utils_1.toKebabCase)(name)}|${(0, utils_1.escapeCharacter)(description || '')}|${(0, utils_1.escapeCharacter)(propertiesTmpl(event.properties)) || '-'}|`;
        if (hasVersion) {
            lineContent += `${version}|`;
        }
        return lineContent;
    })
        .join('\n');
    return {
        content,
        hasVersion,
    };
};
exports.default = (events, lang) => {
    const { content, hasVersion } = tmpl(events, lang);
    if (!content)
        return '';
    const header = lang === 'en'
        ? ['|Event Name|Description|Parameters|', '|---|---|---|']
        : ['|事件名|描述|参数|', '|---|---|---|'];
    if (hasVersion) {
        header[0] += lang === 'en' ? 'version|' : '版本|';
        header[1] += ':---|';
    }
    return `
${header[0]}
${header[1]}
${content}
`;
};
//# sourceMappingURL=events.js.map