"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
const paramsTmpl = (params) => {
    return (params || [])
        .filter((param) => param.type)
        .map((param) => {
        const { name, type, description } = param;
        const res = [];
        name && res.push(name);
        if (type === null || type === void 0 ? void 0 : type.name) {
            res.length && res.push(': ');
            res.push(`\`${type.name}\``);
        }
        description && res.push(description);
        return res.join('');
    })
        .join('\n');
};
const returnsTmpl = (returns) => {
    if (!returns)
        return '';
    const { type, description } = returns;
    if (!type)
        return '';
    const getNames = (type) => {
        const { name, elements } = type;
        if (!elements || !elements.length)
            return name || '';
        const names = [];
        elements.forEach((element) => {
            names.push(getNames(element));
        });
        return `${name}\\<${names.join(',')}\\>`;
    };
    const res = [
        type.name ? `${getNames(type)}` : '',
        description ? ` - ${description}` : '',
    ];
    return res.join('');
};
const tmpl = (methods, lang) => {
    const displayableMethods = methods.filter((method) => { var _a; return method.description || lang in ((_a = method.tags) !== null && _a !== void 0 ? _a : {}); });
    const hasVersion = displayableMethods.some((method) => { var _a; return (_a = method === null || method === void 0 ? void 0 : method.tags) === null || _a === void 0 ? void 0 : _a.version; });
    const content = displayableMethods
        .map((method) => {
        var _a, _b, _c;
        const { name, tags } = method;
        let { description } = method;
        if ((_a = tags === null || tags === void 0 ? void 0 : tags[lang]) === null || _a === void 0 ? void 0 : _a.length) {
            description = tags[lang][0].description;
        }
        const readableParams = paramsTmpl(method.params) || '-';
        const readableReturns = returnsTmpl(method.returns) || '-';
        let lineContent = `|${name}|${(0, utils_1.escapeCharacter)(description || '')}|${(0, utils_1.escapeCharacter)(readableParams)}|${(0, utils_1.escapeCharacter)(readableReturns)}|`;
        if (hasVersion) {
            const version = (_c = (_b = tags === null || tags === void 0 ? void 0 : tags.version) === null || _b === void 0 ? void 0 : _b[0]) === null || _c === void 0 ? void 0 : _c.description;
            lineContent += `${version || ''}|`;
        }
        return lineContent;
    })
        .join('\n');
    return {
        hasVersion,
        content,
    };
};
exports.default = (methods, lang) => {
    const { content, hasVersion } = tmpl(methods, lang);
    if (!content)
        return '';
    const header = lang === 'en'
        ? ['|Method|Description|Parameters|Return|', '|---|---|---|:---:|']
        : ['|方法名|描述|参数|返回值|', '|---|---|---|---|'];
    if (hasVersion) {
        header[0] += lang === 'en' ? 'version|' : '版本|';
        header[1] += ':---|';
    }
    return `
${header[0]}
${header[1]}
${content}
`;
};
//# sourceMappingURL=methods.js.map